@@ -1,4 +1,4 @@
-/*  $Id: french-conjugator.cpp,v 1.17 2009/10/04 03:03:34 sarrazip Exp $
+/*  $Id: french-conjugator.cpp,v 1.18 2010/04/18 20:10:35 sarrazip Exp $
     french-conjugator.cpp - Conjugation of French verbs
 
     verbiste - French conjugation system
@@ -23,6 +23,7 @@
 
 #include "Command.h"
 
+#ifdef ENABLE_NLS
 #ifdef HAVE_GETOPT_LONG
 #include <unistd.h>
 #ifndef _GNU_SOURCE
@@ -30,6 +31,7 @@
 #endif
 #include <getopt.h>
 #endif
+#endif  /* ENABLE_NLS */
 
 #include <langinfo.h>
 
@@ -44,7 +46,7 @@ using namespace verbiste;
 static const char *commandName = "french-conjugator";
 
 
-#ifdef HAVE_GETOPT_LONG
+#if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 static struct option knownOptions[] =
 {
     { "help",           no_argument,            NULL, 'h' },
@@ -58,7 +60,7 @@ static struct option knownOptions[] =
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
-#endif  /* HAVE_GETOPT_LONG */
+#endif
 
 
 class ConjugatorCommand : public Command
@@ -207,7 +209,7 @@ ConjugatorCommand::processInputWord(const string &inputWord)
 }
 
 
-#ifdef HAVE_GETOPT_LONG
+#if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 
 static
 void
@@ -251,7 +253,7 @@ displayHelp()
     ;
 }
 
-#endif  /* ndef HAVE_GETOPT_LONG */
+#endif
 
 
 int
@@ -268,7 +270,7 @@ main(int argc, char *argv[])
     bool includePronouns = false;
     bool listAllInfinitives = false;
 
-    #ifdef HAVE_GETOPT_LONG
+    #if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 
     /*  Interpret the command-line options:
     */
@@ -335,11 +337,11 @@ main(int argc, char *argv[])
 	return EXIT_FAILURE;
     }
 
-    #else  /* ndef HAVE_GETOPT_LONG */
+    #else
 
     int optind = 1;
 
-    #endif  /* ndef HAVE_GETOPT_LONG */
+    #endif
 
     ConjugatorCommand cmd(utf8Mode);
     
