@@ -1,4 +1,4 @@
-/*  $Id: french-deconjugator.cpp,v 1.15 2009/10/04 03:03:34 sarrazip Exp $
+/*  $Id: french-deconjugator.cpp,v 1.16 2010/04/18 20:10:35 sarrazip Exp $
     french-deconjugator.cpp - Analyzer of conjugated French verbs
 
     verbiste - French conjugation system
@@ -23,6 +23,7 @@
 
 #include "Command.h"
 
+#ifdef ENABLE_NLS
 #ifdef HAVE_GETOPT_LONG
 #include <unistd.h>
 #ifndef _GNU_SOURCE
@@ -30,6 +31,7 @@
 #endif
 #include <getopt.h>
 #endif
+#endif  /* ENABLE_NLS */
 
 #include <langinfo.h>
 
@@ -44,7 +46,7 @@ using namespace verbiste;
 static const char *commandName = "french-deconjugator";
 
 
-#ifdef HAVE_GETOPT_LONG
+#if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 static struct option knownOptions[] =
 {
     { "help",          no_argument,       NULL, 'h' },
@@ -54,7 +56,7 @@ static struct option knownOptions[] =
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
-#endif  /* HAVE_GETOPT_LONG */
+#endif
 
 
 class DeconjugatorCommand : public Command
@@ -163,7 +165,7 @@ main(int argc, char *argv[])
     bool utf8Mode = (strcmp(nl_langinfo(CODESET), "UTF-8") == 0);
     bool listAllInfinitives = false;
 
-    #ifdef HAVE_GETOPT_LONG
+    #if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 
     /*  Interpret the command-line options:
     */
@@ -199,11 +201,11 @@ main(int argc, char *argv[])
 	}
     } while (c != EOF && c != '?');
 
-    #else  /* ndef HAVE_GETOPT_LONG */
+    #else
 
     int optind = 1;
 
-    #endif  /* ndef HAVE_GETOPT_LONG */
+    #endif
 
     DeconjugatorCommand cmd(utf8Mode);
 
