@@ -1,4 +1,4 @@
-/*  $Id: gnome-app.cpp,v 1.7 2006/08/28 19:05:25 sarrazip Exp $
+/*  $Id: gnome-app.cpp,v 1.8 2009/03/10 02:59:36 sarrazip Exp $
     gtk-app.cpp - GTK+ application main function
 
     verbiste - French conjugation system
@@ -50,7 +50,8 @@ static
 poptContext
 get_poptContext(GnomeProgram *program)
 {
-    GValue value = { 0, };
+    GValue value;
+    ::memset(&value, '\0', sizeof(value));
     g_value_init(&value, G_TYPE_POINTER);
     g_object_get_property(G_OBJECT(program),
 			    GNOME_PARAM_POPT_CONTEXT, &value);
