@@ -1,4 +1,4 @@
-/*  $Id: conjugation.cpp,v 1.4 2008/01/24 03:28:21 sarrazip Exp $
+/*  $Id: conjugation.cpp,v 1.5 2009/10/31 02:02:05 sarrazip Exp $
     conjugation.cpp - Generic conjugation interface
 
     verbiste - French conjugation system
@@ -44,7 +44,7 @@ initVerbDict() throw(logic_error)
 	libdatadir = LIBDATADIR;
     string conjFN  = libdatadir + string("/") + "conjugation-fr.xml";
     string verbsFN = libdatadir + string("/") + "verbs-fr.xml";
-    return new FrenchVerbDictionary(conjFN, verbsFN);  // may throw
+    return new FrenchVerbDictionary(conjFN, verbsFN, true);  // may throw
 }
 
 
@@ -173,40 +173,14 @@ removePronoun(const string &s)
 }
 
 
-void
-createTableCellText(const VVS &tense,
-			const string &lowerCaseLatin1UserText,
-			const string &openMark,
-			const string &closeMark,
-			VS &inflectionList)
-{
-    for (VVS::const_iterator it = tense.begin(); it != tense.end(); it++)
-    {
-	const VS &person = *it;
-
-	string inf;
-	for (VS::const_iterator i = person.begin(); i != person.end(); i++)
-	{
-	    if (i != person.begin())
-		inf += ", ";
-
-	    if (removePronoun(*i) == lowerCaseLatin1UserText)
-		inf += openMark + *i + closeMark;
-	    else
-		inf += *i;
-	}
-
-	inflectionList.push_back(inf);
-    }
-}
-
-
 string
 createTableCellText(const VVS &tense,
 			const string &lowerCaseLatin1UserText,
 			const string &openMark,
 			const string &closeMark)
 {
+    string userTextWOAccents = FrenchVerbDictionary::removeAccents(lowerCaseLatin1UserText);
+
     string persons;
     for (VVS::const_iterator it = tense.begin(); it != tense.end(); it++)
     {
@@ -220,7 +194,8 @@ createTableCellText(const VVS &tense,
 	    if (i != person.begin())
 		persons += ", ";
 
-	    if (removePronoun(*i) == lowerCaseLatin1UserText)
+	    string inflection = FrenchVerbDictionary::removeAccents(removePronoun(*i));
+	    if (inflection == userTextWOAccents)
 		persons += openMark + *i + closeMark;
 	    else
 		persons += *i;
