@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.h,v 1.22 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.h,v 1.23 2009/10/31 02:02:05 sarrazip Exp $
     FrenchVerbDictionary.h - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -54,23 +54,28 @@ public:
 	@param	verbsFilename		filename of the XML document that
 					defines all the known verbs and their
 					corresponding template
+	@param	includeWithoutAccents	include in the knowledge base variants
+					verbs where some or all accents are missing
 	@throws	logic_error		for invalid filename arguments,
 					unparseable or unexpected XML documents
 					(if verbs or template names are
 					mentioned, they are in Latin-1)
     */
     FrenchVerbDictionary(const std::string &conjugationFilename,
-			const std::string &verbsFilename)
+			const std::string &verbsFilename,
+			bool includeWithoutAccents)
 					throw (std::logic_error);
 
     /** Load the french conjugation database.
 	Uses the default (hard-coded) location for the data filenames.
+	@param	includeWithoutAccents	include in the knowledge base variants
+					verbs where some or all accents are missing
 	@throws	logic_error		for invalid filename arguments,
 					unparseable or unexpected XML documents
 					(if verbs or template names are
 					mentioned, they are in Latin-1)
     */
-    FrenchVerbDictionary() throw (std::logic_error);
+    FrenchVerbDictionary(bool includeWithoutAccents) throw (std::logic_error);
 
     /** Destroys this object, but NOT the internal trie, to save time.
 	CAUTION:
@@ -210,6 +215,29 @@ public:
     void utf8ToLatin1(
 		std::vector<std::vector<std::string> > &vec) const throw(int);
 
+    /** Removes accents from accented letters in the given string.
+        @param	latin1String	ISO-8859-1 string with accented characters
+	@returns		a Latin-1 string with the accents removed
+    */
+    static std::string removeAccents(const std::string &latin1String);
+
+    /** Returns all unaccented variants of a string.
+	If N letters are accented in 'latin1String', then 2^N variants
+	are returned, where each accented letter either keeps or loses
+	its accents.
+	For example, the word "été" has 3 unaccented variants:
+	"eté", "ete" and "éte".
+        @param	latin1String	ISO-8859-1 string with accented characters
+	@param	index		pass zero (recursive calls to this function
+				pass non-zero indices)
+	@param	variants	vector to which Latin-1 strings are added
+				with push_back (this function does not
+				clear the vector beforehand)
+    */
+    static void formUnaccentedVariants(const string &latin1String,
+					size_t index,
+					vector<string> &variants);
+
     /**	Returns the content of an XML node in Latin-1.
 	@param	doc		the XML document
 	@param	node		the node of the XML document whose contents
@@ -348,16 +376,23 @@ private:
 
 
     void init(const std::string &conjugationFilename,
-			const std::string &verbsFilename)
+			const std::string &verbsFilename,
+			bool includeWithoutAccents)
 					throw (std::logic_error);
-    void loadConjugationDatabase(const char *conjugationFilename)
+    void loadConjugationDatabase(const char *conjugationFilename,
+				bool includeWithoutAccents)
 					throw (std::logic_error);
-    void loadVerbDatabase(const char *verbsFilename)
+    void loadVerbDatabase(const char *verbsFilename,
+			bool includeWithoutAccents)
 					throw (std::logic_error);
-    void readConjugation(xmlDocPtr doc) throw(std::logic_error);
+    void readConjugation(xmlDocPtr doc,
+			bool includeWithoutAccents) throw(std::logic_error);
     static void generateOtherPastParticiple(const char *mascSing,
 					std::vector<std::string> &dest);
-    void readVerbs(xmlDocPtr doc) throw(std::logic_error);
+    void readVerbs(xmlDocPtr doc,
+		   bool includeWithoutAccents)
+				throw(std::logic_error);
+    void insertVerbRadicalInTrie(const string &verbRadical, const string &tname);
 
     // Forbidden operations:
     FrenchVerbDictionary(const FrenchVerbDictionary &x);
